# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: applications_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import objects_pb2 as objects__pb2
from . import sort_direction_pb2 as sort__direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61pplications_common.proto\x12 armonik.api.grpc.v1.applications\x1a\robjects.proto\x1a\x14sort_direction.proto\"S\n\x0e\x41pplicationRaw\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\"_\n\x13\x41pplicationRawField\x12H\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x39.armonik.api.grpc.v1.applications.ApplicationRawEnumField\"o\n\x10\x41pplicationField\x12R\n\x11\x61pplication_field\x18\x01 \x01(\x0b\x32\x35.armonik.api.grpc.v1.applications.ApplicationRawFieldH\x00\x42\x07\n\x05\x66ield\"\xba\x03\n\x17ListApplicationsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12P\n\x06\x66ilter\x18\x03 \x01(\x0b\x32@.armonik.api.grpc.v1.applications.ListApplicationsRequest.Filter\x12L\n\x04sort\x18\x04 \x01(\x0b\x32>.armonik.api.grpc.v1.applications.ListApplicationsRequest.Sort\x1aK\n\x06\x46ilter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x1a\x90\x01\n\x04Sort\x12\x42\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x32.armonik.api.grpc.v1.applications.ApplicationField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"\x92\x01\n\x18ListApplicationsResponse\x12\x46\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32\x30.armonik.api.grpc.v1.applications.ApplicationRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\":\n\x19\x43ountTasksByStatusRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"N\n\x1a\x43ountTasksByStatusResponse\x12\x30\n\x06status\x18\x01 \x03(\x0b\x32 .armonik.api.grpc.v1.StatusCount*\xe4\x01\n\x17\x41pplicationRawEnumField\x12*\n&APPLICATION_RAW_ENUM_FIELD_UNSPECIFIED\x10\x00\x12#\n\x1f\x41PPLICATION_RAW_ENUM_FIELD_NAME\x10\x01\x12&\n\"APPLICATION_RAW_ENUM_FIELD_VERSION\x10\x02\x12(\n$APPLICATION_RAW_ENUM_FIELD_NAMESPACE\x10\x03\x12&\n\"APPLICATION_RAW_ENUM_FIELD_SERVICE\x10\x04\x42#\xaa\x02 ArmoniK.Api.gRPC.V1.Applicationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'applications_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002 ArmoniK.Api.gRPC.V1.Applications'
  _globals['_APPLICATIONRAWENUMFIELD']._serialized_start=1130
  _globals['_APPLICATIONRAWENUMFIELD']._serialized_end=1358
  _globals['_APPLICATIONRAW']._serialized_start=100
  _globals['_APPLICATIONRAW']._serialized_end=183
  _globals['_APPLICATIONRAWFIELD']._serialized_start=185
  _globals['_APPLICATIONRAWFIELD']._serialized_end=280
  _globals['_APPLICATIONFIELD']._serialized_start=282
  _globals['_APPLICATIONFIELD']._serialized_end=393
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_start=396
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_end=838
  _globals['_LISTAPPLICATIONSREQUEST_FILTER']._serialized_start=616
  _globals['_LISTAPPLICATIONSREQUEST_FILTER']._serialized_end=691
  _globals['_LISTAPPLICATIONSREQUEST_SORT']._serialized_start=694
  _globals['_LISTAPPLICATIONSREQUEST_SORT']._serialized_end=838
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_start=841
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_end=987
  _globals['_COUNTTASKSBYSTATUSREQUEST']._serialized_start=989
  _globals['_COUNTTASKSBYSTATUSREQUEST']._serialized_end=1047
  _globals['_COUNTTASKSBYSTATUSRESPONSE']._serialized_start=1049
  _globals['_COUNTTASKSBYSTATUSRESPONSE']._serialized_end=1127
# @@protoc_insertion_point(module_scope)
