# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import objects_pb2 as objects__pb2
from . import result_status_pb2 as result__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61gent_common.proto\x12\x19\x61rmonik.api.grpc.v1.agent\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\robjects.proto\x1a\x13result_status.proto\"\xc4\x02\n\x11\x43reateTaskRequest\x12P\n\x0cinit_request\x18\x01 \x01(\x0b\x32\x38.armonik.api.grpc.v1.agent.CreateTaskRequest.InitRequestH\x00\x12\x39\n\tinit_task\x18\x02 \x01(\x0b\x32$.armonik.api.grpc.v1.InitTaskRequestH\x00\x12\x36\n\x0ctask_payload\x18\x03 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x1b\n\x13\x63ommunication_token\x18\x04 \x01(\t\x1a\x45\n\x0bInitRequest\x12\x36\n\x0ctask_options\x18\x01 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptionsB\x06\n\x04type\"\xf7\x03\n\x0f\x43reateTaskReply\x12]\n\x14\x63reation_status_list\x18\x01 \x01(\x0b\x32=.armonik.api.grpc.v1.agent.CreateTaskReply.CreationStatusListH\x00\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x12\x1b\n\x13\x63ommunication_token\x18\x04 \x01(\t\x1ah\n\x08TaskInfo\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpected_output_keys\x18\x02 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x03 \x03(\t\x12\x12\n\npayload_id\x18\x04 \x01(\t\x1au\n\x0e\x43reationStatus\x12H\n\ttask_info\x18\x01 \x01(\x0b\x32\x33.armonik.api.grpc.v1.agent.CreateTaskReply.TaskInfoH\x00\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x42\x08\n\x06Status\x1aj\n\x12\x43reationStatusList\x12T\n\x11\x63reation_statuses\x18\x01 \x03(\x0b\x32\x39.armonik.api.grpc.v1.agent.CreateTaskReply.CreationStatusB\n\n\x08Response\"7\n\x0b\x44\x61taRequest\x12\x1b\n\x13\x63ommunication_token\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\x90\x02\n\tDataReply\x12\x1b\n\x13\x63ommunication_token\x18\x01 \x01(\t\x12\x39\n\x04init\x18\x02 \x01(\x0b\x32).armonik.api.grpc.v1.agent.DataReply.InitH\x00\x12.\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x0f\n\x05\x65rror\x18\x04 \x01(\tH\x00\x1a\x62\n\x04Init\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x0f\n\x05\x65rror\x18\x03 \x01(\tH\x00\x42\x0c\n\nhas_resultB\x06\n\x04type\"\x97\x01\n\x06Result\x12\x38\n\x04init\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.InitKeyedDataStreamH\x00\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x1b\n\x13\x63ommunication_token\x18\x03 \x01(\tB\x06\n\x04type\"m\n\x0bResultReply\x12\x1b\n\x13\x63ommunication_token\x18\x03 \x01(\t\x12(\n\x02Ok\x18\x01 \x01(\x0b\x32\x1a.armonik.api.grpc.v1.EmptyH\x00\x12\x0f\n\x05\x45rror\x18\x02 \x01(\tH\x00\x42\x06\n\x04type\"\xc4\x01\n\x1c\x43reateResultsMetaDataRequest\x12U\n\x07results\x18\x01 \x03(\x0b\x32\x44.armonik.api.grpc.v1.agent.CreateResultsMetaDataRequest.ResultCreate\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x1b\n\x13\x63ommunication_token\x18\x03 \x01(\t\x1a\x1c\n\x0cResultCreate\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb6\x01\n\x0eResultMetaData\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12?\n\x06status\x18\x04 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"x\n\x1d\x43reateResultsMetaDataResponse\x12:\n\x07results\x18\x01 \x03(\x0b\x32).armonik.api.grpc.v1.agent.ResultMetaData\x12\x1b\n\x13\x63ommunication_token\x18\x02 \x01(\t\"\xe7\x02\n\x12SubmitTasksRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x36\n\x0ctask_options\x18\x02 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12R\n\x0etask_creations\x18\x03 \x03(\x0b\x32:.armonik.api.grpc.v1.agent.SubmitTasksRequest.TaskCreation\x12\x1b\n\x13\x63ommunication_token\x18\x04 \x01(\t\x1a\x93\x01\n\x0cTaskCreation\x12\x1c\n\x14\x65xpected_output_keys\x18\x01 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x02 \x03(\t\x12\x12\n\npayload_id\x18\x03 \x01(\t\x12\x36\n\x0ctask_options\x18\x04 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\"\xe8\x01\n\x13SubmitTasksResponse\x12K\n\ntask_infos\x18\x01 \x03(\x0b\x32\x37.armonik.api.grpc.v1.agent.SubmitTasksResponse.TaskInfo\x12\x1b\n\x13\x63ommunication_token\x18\x02 \x01(\t\x1ag\n\x08TaskInfo\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x1b\n\x13\x65xpected_output_ids\x18\x02 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x03 \x03(\t\x12\x12\n\npayload_id\x18\x04 \x01(\t\"\xc2\x01\n\x14\x43reateResultsRequest\x12M\n\x07results\x18\x01 \x03(\x0b\x32<.armonik.api.grpc.v1.agent.CreateResultsRequest.ResultCreate\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x1b\n\x13\x63ommunication_token\x18\x03 \x01(\t\x1a*\n\x0cResultCreate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"p\n\x15\x43reateResultsResponse\x12:\n\x07results\x18\x01 \x03(\x0b\x32).armonik.api.grpc.v1.agent.ResultMetaData\x12\x1b\n\x13\x63ommunication_token\x18\x02 \x01(\t\"\xe2\x01\n\x17UploadResultDataRequest\x12Q\n\x02id\x18\x01 \x01(\x0b\x32\x43.armonik.api.grpc.v1.agent.UploadResultDataRequest.ResultIdentifierH\x00\x12\x14\n\ndata_chunk\x18\x02 \x01(\x0cH\x00\x12\x1b\n\x13\x63ommunication_token\x18\x04 \x01(\t\x1a\x39\n\x10ResultIdentifier\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x01(\tB\x06\n\x04type\"J\n\x18UploadResultDataResponse\x12\x11\n\tresult_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ommunication_token\x18\x02 \x01(\tB\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Agent'
  _globals['_CREATETASKREQUEST']._serialized_start=119
  _globals['_CREATETASKREQUEST']._serialized_end=443
  _globals['_CREATETASKREQUEST_INITREQUEST']._serialized_start=366
  _globals['_CREATETASKREQUEST_INITREQUEST']._serialized_end=435
  _globals['_CREATETASKREPLY']._serialized_start=446
  _globals['_CREATETASKREPLY']._serialized_end=949
  _globals['_CREATETASKREPLY_TASKINFO']._serialized_start=606
  _globals['_CREATETASKREPLY_TASKINFO']._serialized_end=710
  _globals['_CREATETASKREPLY_CREATIONSTATUS']._serialized_start=712
  _globals['_CREATETASKREPLY_CREATIONSTATUS']._serialized_end=829
  _globals['_CREATETASKREPLY_CREATIONSTATUSLIST']._serialized_start=831
  _globals['_CREATETASKREPLY_CREATIONSTATUSLIST']._serialized_end=937
  _globals['_DATAREQUEST']._serialized_start=951
  _globals['_DATAREQUEST']._serialized_end=1006
  _globals['_DATAREPLY']._serialized_start=1009
  _globals['_DATAREPLY']._serialized_end=1281
  _globals['_DATAREPLY_INIT']._serialized_start=1175
  _globals['_DATAREPLY_INIT']._serialized_end=1273
  _globals['_RESULT']._serialized_start=1284
  _globals['_RESULT']._serialized_end=1435
  _globals['_RESULTREPLY']._serialized_start=1437
  _globals['_RESULTREPLY']._serialized_end=1546
  _globals['_CREATERESULTSMETADATAREQUEST']._serialized_start=1549
  _globals['_CREATERESULTSMETADATAREQUEST']._serialized_end=1745
  _globals['_CREATERESULTSMETADATAREQUEST_RESULTCREATE']._serialized_start=1717
  _globals['_CREATERESULTSMETADATAREQUEST_RESULTCREATE']._serialized_end=1745
  _globals['_RESULTMETADATA']._serialized_start=1748
  _globals['_RESULTMETADATA']._serialized_end=1930
  _globals['_CREATERESULTSMETADATARESPONSE']._serialized_start=1932
  _globals['_CREATERESULTSMETADATARESPONSE']._serialized_end=2052
  _globals['_SUBMITTASKSREQUEST']._serialized_start=2055
  _globals['_SUBMITTASKSREQUEST']._serialized_end=2414
  _globals['_SUBMITTASKSREQUEST_TASKCREATION']._serialized_start=2267
  _globals['_SUBMITTASKSREQUEST_TASKCREATION']._serialized_end=2414
  _globals['_SUBMITTASKSRESPONSE']._serialized_start=2417
  _globals['_SUBMITTASKSRESPONSE']._serialized_end=2649
  _globals['_SUBMITTASKSRESPONSE_TASKINFO']._serialized_start=2546
  _globals['_SUBMITTASKSRESPONSE_TASKINFO']._serialized_end=2649
  _globals['_CREATERESULTSREQUEST']._serialized_start=2652
  _globals['_CREATERESULTSREQUEST']._serialized_end=2846
  _globals['_CREATERESULTSREQUEST_RESULTCREATE']._serialized_start=2804
  _globals['_CREATERESULTSREQUEST_RESULTCREATE']._serialized_end=2846
  _globals['_CREATERESULTSRESPONSE']._serialized_start=2848
  _globals['_CREATERESULTSRESPONSE']._serialized_end=2960
  _globals['_UPLOADRESULTDATAREQUEST']._serialized_start=2963
  _globals['_UPLOADRESULTDATAREQUEST']._serialized_end=3189
  _globals['_UPLOADRESULTDATAREQUEST_RESULTIDENTIFIER']._serialized_start=3124
  _globals['_UPLOADRESULTDATAREQUEST_RESULTIDENTIFIER']._serialized_end=3181
  _globals['_UPLOADRESULTDATARESPONSE']._serialized_start=3191
  _globals['_UPLOADRESULTDATARESPONSE']._serialized_end=3265
# @@protoc_insertion_point(module_scope)
